@@ -62,6 +62,6 @@ var searchData=
   ['uno_5ftype_5fsequence_5fdestroy_59',['uno_type_sequence_destroy',['../a00296.html#a8b0bc4cc6acfac970f79fe2f8352f564',1,'sequence2.h']]],
   ['uno_5ftype_5fsequence_5frealloc_60',['uno_type_sequence_realloc',['../a00296.html#a1448f50fc11735e422fe9ffe11b880ec',1,'sequence2.h']]],
   ['uno_5ftype_5fsequence_5freference2one_61',['uno_type_sequence_reference2One',['../a00296.html#a707ab70bf1b37f59d36f7afe642982b3',1,'sequence2.h']]],
-  ['unourl_62',['UnoUrl',['../a01942.html#af74f9f63ba57a8664ce63da416fa7b83',1,'cppu::UnoUrl::UnoUrl(rtl::OUString const &amp;rUrl)'],['../a01942.html#a23b5e876eecd29a9f1e5161b1e3a8407',1,'cppu::UnoUrl::UnoUrl(UnoUrl const &amp;rOther)']]],
-  ['unourldescriptor_63',['UnoUrlDescriptor',['../a01938.html#a35adf9b2722dcfe5dd0cf0a0588e2ac2',1,'cppu::UnoUrlDescriptor::UnoUrlDescriptor(rtl::OUString const &amp;rDescriptor)'],['../a01938.html#adc91019dd09706a1e8a083244967f78d',1,'cppu::UnoUrlDescriptor::UnoUrlDescriptor(UnoUrlDescriptor const &amp;rOther)']]]
+  ['unourl_62',['unourl',['../a01942.html#af74f9f63ba57a8664ce63da416fa7b83',1,'cppu::UnoUrl::UnoUrl(rtl::OUString const &amp;rUrl)'],['../a01942.html#a23b5e876eecd29a9f1e5161b1e3a8407',1,'cppu::UnoUrl::UnoUrl(UnoUrl const &amp;rOther)']]],
+  ['unourldescriptor_63',['unourldescriptor',['../a01938.html#a35adf9b2722dcfe5dd0cf0a0588e2ac2',1,'cppu::UnoUrlDescriptor::UnoUrlDescriptor(rtl::OUString const &amp;rDescriptor)'],['../a01938.html#adc91019dd09706a1e8a083244967f78d',1,'cppu::UnoUrlDescriptor::UnoUrlDescriptor(UnoUrlDescriptor const &amp;rOther)']]]
 ];
