@@ -9,7 +9,7 @@ var searchData=
   ['chartdatapoint_6',['ChartDataPoint',['../namespacecom_1_1sun_1_1star_1_1chart.html#a9335f12de589754bf3632ff79ad2e520',1,'com::sun::star::chart']]],
   ['choices_7',['Choices',['../structcom_1_1sun_1_1star_1_1sdbc_1_1DriverPropertyInfo.html#acdf2a8d50cc19e1b3b0a7eb3ee206a0c',1,'com::sun::star::sdbc::DriverPropertyInfo']]],
   ['cmisproperties_8',['CmisProperties',['../interfacecom_1_1sun_1_1star_1_1document_1_1XCmisDocument.html#a5b8207c3a83025d53ccfdf8fa9356c03',1,'com::sun::star::document::XCmisDocument']]],
-  ['color_9',['Color',['../namespacecom_1_1sun_1_1star_1_1util.html#a1eba7fdd59cb0581d2b072a5798bd75d',1,'com::sun::star::util::Color()'],['../namespacecom_1_1sun_1_1star_1_1rendering.html#a6e6c5d8e54f930a67b20875cb6300ef2',1,'com::sun::star::rendering::Color()']]],
+  ['color_9',['color',['../namespacecom_1_1sun_1_1star_1_1util.html#a1eba7fdd59cb0581d2b072a5798bd75d',1,'com::sun::star::util::Color'],['../namespacecom_1_1sun_1_1star_1_1rendering.html#a6e6c5d8e54f930a67b20875cb6300ef2',1,'com::sun::star::rendering::Color']]],
   ['colorcomponent_10',['ColorComponent',['../namespacecom_1_1sun_1_1star_1_1rendering.html#a22cfb0d628f89a8edb356ae3231d4e22',1,'com::sun::star::rendering']]],
   ['colorscaleentries_11',['ColorScaleEntries',['../servicecom_1_1sun_1_1star_1_1sheet_1_1ColorScale.html#ab56ac80a190cd9175c8c23f1723ad6cc',1,'com::sun::star::sheet::ColorScale']]],
   ['columnnames_12',['Columnnames',['../interfacecom_1_1sun_1_1star_1_1logging_1_1XCsvLogFormatter.html#a99bd961b783cd590028a5d1f66ef5e02',1,'com::sun::star::logging::XCsvLogFormatter']]],
@@ -25,5 +25,5 @@ var searchData=
   ['creationarguments_22',['CreationArguments',['../interfacecom_1_1sun_1_1star_1_1frame_1_1XController2.html#a7e6db858a69869a7377f36ea51a2f441',1,'com::sun::star::frame::XController2']]],
   ['criteria_23',['Criteria',['../structcom_1_1sun_1_1star_1_1ucb_1_1SearchInfo.html#ad00f2f44f640b57f6f1bcb7a1d6c20c7',1,'com::sun::star::ucb::SearchInfo']]],
   ['customlabelfields_24',['CustomLabelFields',['../servicecom_1_1sun_1_1star_1_1chart2_1_1DataPointProperties.html#afadb18024e7634b9c0d029462840af23',1,'com::sun::star::chart2::DataPointProperties']]],
-  ['customshapegeometry_25',['CustomShapeGeometry',['../interfacecom_1_1sun_1_1star_1_1report_1_1XShape.html#ab32992b6ac0900fdd336e55a99f87436',1,'com::sun::star::report::XShape::CustomShapeGeometry()'],['../servicecom_1_1sun_1_1star_1_1drawing_1_1CustomShape.html#ab32992b6ac0900fdd336e55a99f87436',1,'com::sun::star::drawing::CustomShape::CustomShapeGeometry()']]]
+  ['customshapegeometry_25',['customshapegeometry',['../interfacecom_1_1sun_1_1star_1_1report_1_1XShape.html#ab32992b6ac0900fdd336e55a99f87436',1,'com::sun::star::report::XShape::CustomShapeGeometry'],['../servicecom_1_1sun_1_1star_1_1drawing_1_1CustomShape.html#ab32992b6ac0900fdd336e55a99f87436',1,'com::sun::star::drawing::CustomShape::CustomShapeGeometry']]]
 ];
